
/* Generated data (by glib-mkenums) */

#include "cogl-enum-types.h"
#include "cogl.h"

/* enumerations from "./cogl-buffer.h" */
#include "./cogl-buffer.h"

GType
cogl_buffer_usage_hint_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_BUFFER_USAGE_HINT_TEXTURE, "COGL_BUFFER_USAGE_HINT_TEXTURE", "texture" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglBufferUsageHint"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_buffer_update_hint_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_BUFFER_UPDATE_HINT_STATIC, "COGL_BUFFER_UPDATE_HINT_STATIC", "static" },
        { COGL_BUFFER_UPDATE_HINT_DYNAMIC, "COGL_BUFFER_UPDATE_HINT_DYNAMIC", "dynamic" },
        { COGL_BUFFER_UPDATE_HINT_STREAM, "COGL_BUFFER_UPDATE_HINT_STREAM", "stream" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglBufferUpdateHint"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_buffer_access_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_BUFFER_ACCESS_READ, "COGL_BUFFER_ACCESS_READ", "read" },
        { COGL_BUFFER_ACCESS_WRITE, "COGL_BUFFER_ACCESS_WRITE", "write" },
        { COGL_BUFFER_ACCESS_READ_WRITE, "COGL_BUFFER_ACCESS_READ_WRITE", "read-write" },
        { COGL_BUFFER_ACCESS_WRITE, "COGL_BUFFER_ACCESS_WRITE", "write" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglBufferAccess"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-debug.h" */
#include "./cogl-debug.h"

GType
cogl_debug_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_DEBUG_SLICING, "COGL_DEBUG_SLICING", "slicing" },
        { COGL_DEBUG_OFFSCREEN, "COGL_DEBUG_OFFSCREEN", "offscreen" },
        { COGL_DEBUG_DRAW, "COGL_DEBUG_DRAW", "draw" },
        { COGL_DEBUG_PANGO, "COGL_DEBUG_PANGO", "pango" },
        { COGL_DEBUG_RECTANGLES, "COGL_DEBUG_RECTANGLES", "rectangles" },
        { COGL_DEBUG_HANDLE, "COGL_DEBUG_HANDLE", "handle" },
        { COGL_DEBUG_BLEND_STRINGS, "COGL_DEBUG_BLEND_STRINGS", "blend-strings" },
        { COGL_DEBUG_DISABLE_BATCHING, "COGL_DEBUG_DISABLE_BATCHING", "disable-batching" },
        { COGL_DEBUG_DISABLE_VBOS, "COGL_DEBUG_DISABLE_VBOS", "disable-vbos" },
        { COGL_DEBUG_JOURNAL, "COGL_DEBUG_JOURNAL", "journal" },
        { COGL_DEBUG_BATCHING, "COGL_DEBUG_BATCHING", "batching" },
        { COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM, "COGL_DEBUG_DISABLE_SOFTWARE_TRANSFORM", "disable-software-transform" },
        { COGL_DEBUG_MATRICES, "COGL_DEBUG_MATRICES", "matrices" },
        { COGL_DEBUG_ATLAS, "COGL_DEBUG_ATLAS", "atlas" },
        { COGL_DEBUG_DUMP_ATLAS_IMAGE, "COGL_DEBUG_DUMP_ATLAS_IMAGE", "dump-atlas-image" },
        { COGL_DEBUG_DISABLE_ATLAS, "COGL_DEBUG_DISABLE_ATLAS", "disable-atlas" },
        { COGL_DEBUG_OPENGL, "COGL_DEBUG_OPENGL", "opengl" },
        { COGL_DEBUG_DISABLE_TEXTURING, "COGL_DEBUG_DISABLE_TEXTURING", "disable-texturing" },
        { COGL_DEBUG_DISABLE_ARBFP, "COGL_DEBUG_DISABLE_ARBFP", "disable-arbfp" },
        { COGL_DEBUG_DISABLE_GLSL, "COGL_DEBUG_DISABLE_GLSL", "disable-glsl" },
        { COGL_DEBUG_SHOW_SOURCE, "COGL_DEBUG_SHOW_SOURCE", "show-source" },
        { COGL_DEBUG_DISABLE_BLENDING, "COGL_DEBUG_DISABLE_BLENDING", "disable-blending" },
        { COGL_DEBUG_TEXTURE_PIXMAP, "COGL_DEBUG_TEXTURE_PIXMAP", "texture-pixmap" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglDebugFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-material.h" */
#include "./cogl-material.h"

GType
cogl_material_filter_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_MATERIAL_FILTER_NEAREST, "COGL_MATERIAL_FILTER_NEAREST", "nearest" },
        { COGL_MATERIAL_FILTER_LINEAR, "COGL_MATERIAL_FILTER_LINEAR", "linear" },
        { COGL_MATERIAL_FILTER_NEAREST_MIPMAP_NEAREST, "COGL_MATERIAL_FILTER_NEAREST_MIPMAP_NEAREST", "nearest-mipmap-nearest" },
        { COGL_MATERIAL_FILTER_LINEAR_MIPMAP_NEAREST, "COGL_MATERIAL_FILTER_LINEAR_MIPMAP_NEAREST", "linear-mipmap-nearest" },
        { COGL_MATERIAL_FILTER_NEAREST_MIPMAP_LINEAR, "COGL_MATERIAL_FILTER_NEAREST_MIPMAP_LINEAR", "nearest-mipmap-linear" },
        { COGL_MATERIAL_FILTER_LINEAR_MIPMAP_LINEAR, "COGL_MATERIAL_FILTER_LINEAR_MIPMAP_LINEAR", "linear-mipmap-linear" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglMaterialFilter"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_material_wrap_mode_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_MATERIAL_WRAP_MODE_REPEAT, "COGL_MATERIAL_WRAP_MODE_REPEAT", "repeat" },
        { COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE, "COGL_MATERIAL_WRAP_MODE_CLAMP_TO_EDGE", "clamp-to-edge" },
        { COGL_MATERIAL_WRAP_MODE_AUTOMATIC, "COGL_MATERIAL_WRAP_MODE_AUTOMATIC", "automatic" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglMaterialWrapMode"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_material_alpha_func_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_MATERIAL_ALPHA_FUNC_NEVER, "COGL_MATERIAL_ALPHA_FUNC_NEVER", "never" },
        { COGL_MATERIAL_ALPHA_FUNC_LESS, "COGL_MATERIAL_ALPHA_FUNC_LESS", "less" },
        { COGL_MATERIAL_ALPHA_FUNC_EQUAL, "COGL_MATERIAL_ALPHA_FUNC_EQUAL", "equal" },
        { COGL_MATERIAL_ALPHA_FUNC_LEQUAL, "COGL_MATERIAL_ALPHA_FUNC_LEQUAL", "lequal" },
        { COGL_MATERIAL_ALPHA_FUNC_GREATER, "COGL_MATERIAL_ALPHA_FUNC_GREATER", "greater" },
        { COGL_MATERIAL_ALPHA_FUNC_NOTEQUAL, "COGL_MATERIAL_ALPHA_FUNC_NOTEQUAL", "notequal" },
        { COGL_MATERIAL_ALPHA_FUNC_GEQUAL, "COGL_MATERIAL_ALPHA_FUNC_GEQUAL", "gequal" },
        { COGL_MATERIAL_ALPHA_FUNC_ALWAYS, "COGL_MATERIAL_ALPHA_FUNC_ALWAYS", "always" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglMaterialAlphaFunc"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_material_layer_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_MATERIAL_LAYER_TYPE_TEXTURE, "COGL_MATERIAL_LAYER_TYPE_TEXTURE", "texture" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglMaterialLayerType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_depth_test_function_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_DEPTH_TEST_FUNCTION_NEVER, "COGL_DEPTH_TEST_FUNCTION_NEVER", "never" },
        { COGL_DEPTH_TEST_FUNCTION_LESS, "COGL_DEPTH_TEST_FUNCTION_LESS", "less" },
        { COGL_DEPTH_TEST_FUNCTION_EQUAL, "COGL_DEPTH_TEST_FUNCTION_EQUAL", "equal" },
        { COGL_DEPTH_TEST_FUNCTION_LEQUAL, "COGL_DEPTH_TEST_FUNCTION_LEQUAL", "lequal" },
        { COGL_DEPTH_TEST_FUNCTION_GREATER, "COGL_DEPTH_TEST_FUNCTION_GREATER", "greater" },
        { COGL_DEPTH_TEST_FUNCTION_NOTEQUAL, "COGL_DEPTH_TEST_FUNCTION_NOTEQUAL", "notequal" },
        { COGL_DEPTH_TEST_FUNCTION_GEQUAL, "COGL_DEPTH_TEST_FUNCTION_GEQUAL", "gequal" },
        { COGL_DEPTH_TEST_FUNCTION_ALWAYS, "COGL_DEPTH_TEST_FUNCTION_ALWAYS", "always" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglDepthTestFunction"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-path.h" */
#include "./cogl-path.h"

GType
cogl_path_fill_rule_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_PATH_FILL_RULE_NON_ZERO, "COGL_PATH_FILL_RULE_NON_ZERO", "non-zero" },
        { COGL_PATH_FILL_RULE_EVEN_ODD, "COGL_PATH_FILL_RULE_EVEN_ODD", "even-odd" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglPathFillRule"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-shader.h" */
#include "./cogl-shader.h"

GType
cogl_shader_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_SHADER_TYPE_VERTEX, "COGL_SHADER_TYPE_VERTEX", "vertex" },
        { COGL_SHADER_TYPE_FRAGMENT, "COGL_SHADER_TYPE_FRAGMENT", "fragment" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglShaderType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-types.h" */
#include "./cogl-types.h"

GType
cogl_pixel_format_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_PIXEL_FORMAT_ANY, "COGL_PIXEL_FORMAT_ANY", "any" },
        { COGL_PIXEL_FORMAT_A_8, "COGL_PIXEL_FORMAT_A_8", "a-8" },
        { COGL_PIXEL_FORMAT_RGB_565, "COGL_PIXEL_FORMAT_RGB_565", "rgb-565" },
        { COGL_PIXEL_FORMAT_RGBA_4444, "COGL_PIXEL_FORMAT_RGBA_4444", "rgba-4444" },
        { COGL_PIXEL_FORMAT_RGBA_5551, "COGL_PIXEL_FORMAT_RGBA_5551", "rgba-5551" },
        { COGL_PIXEL_FORMAT_YUV, "COGL_PIXEL_FORMAT_YUV", "yuv" },
        { COGL_PIXEL_FORMAT_G_8, "COGL_PIXEL_FORMAT_G_8", "g-8" },
        { COGL_PIXEL_FORMAT_RGB_888, "COGL_PIXEL_FORMAT_RGB_888", "rgb-888" },
        { COGL_PIXEL_FORMAT_BGR_888, "COGL_PIXEL_FORMAT_BGR_888", "bgr-888" },
        { COGL_PIXEL_FORMAT_RGBA_8888, "COGL_PIXEL_FORMAT_RGBA_8888", "rgba-8888" },
        { COGL_PIXEL_FORMAT_BGRA_8888, "COGL_PIXEL_FORMAT_BGRA_8888", "bgra-8888" },
        { COGL_PIXEL_FORMAT_ARGB_8888, "COGL_PIXEL_FORMAT_ARGB_8888", "argb-8888" },
        { COGL_PIXEL_FORMAT_ABGR_8888, "COGL_PIXEL_FORMAT_ABGR_8888", "abgr-8888" },
        { COGL_PIXEL_FORMAT_RGBA_8888_PRE, "COGL_PIXEL_FORMAT_RGBA_8888_PRE", "rgba-8888-pre" },
        { COGL_PIXEL_FORMAT_BGRA_8888_PRE, "COGL_PIXEL_FORMAT_BGRA_8888_PRE", "bgra-8888-pre" },
        { COGL_PIXEL_FORMAT_ARGB_8888_PRE, "COGL_PIXEL_FORMAT_ARGB_8888_PRE", "argb-8888-pre" },
        { COGL_PIXEL_FORMAT_ABGR_8888_PRE, "COGL_PIXEL_FORMAT_ABGR_8888_PRE", "abgr-8888-pre" },
        { COGL_PIXEL_FORMAT_RGBA_4444_PRE, "COGL_PIXEL_FORMAT_RGBA_4444_PRE", "rgba-4444-pre" },
        { COGL_PIXEL_FORMAT_RGBA_5551_PRE, "COGL_PIXEL_FORMAT_RGBA_5551_PRE", "rgba-5551-pre" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglPixelFormat"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_feature_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_FEATURE_TEXTURE_RECTANGLE, "COGL_FEATURE_TEXTURE_RECTANGLE", "texture-rectangle" },
        { COGL_FEATURE_TEXTURE_NPOT, "COGL_FEATURE_TEXTURE_NPOT", "texture-npot" },
        { COGL_FEATURE_TEXTURE_YUV, "COGL_FEATURE_TEXTURE_YUV", "texture-yuv" },
        { COGL_FEATURE_TEXTURE_READ_PIXELS, "COGL_FEATURE_TEXTURE_READ_PIXELS", "texture-read-pixels" },
        { COGL_FEATURE_SHADERS_GLSL, "COGL_FEATURE_SHADERS_GLSL", "shaders-glsl" },
        { COGL_FEATURE_OFFSCREEN, "COGL_FEATURE_OFFSCREEN", "offscreen" },
        { COGL_FEATURE_OFFSCREEN_MULTISAMPLE, "COGL_FEATURE_OFFSCREEN_MULTISAMPLE", "offscreen-multisample" },
        { COGL_FEATURE_OFFSCREEN_BLIT, "COGL_FEATURE_OFFSCREEN_BLIT", "offscreen-blit" },
        { COGL_FEATURE_FOUR_CLIP_PLANES, "COGL_FEATURE_FOUR_CLIP_PLANES", "four-clip-planes" },
        { COGL_FEATURE_STENCIL_BUFFER, "COGL_FEATURE_STENCIL_BUFFER", "stencil-buffer" },
        { COGL_FEATURE_VBOS, "COGL_FEATURE_VBOS", "vbos" },
        { COGL_FEATURE_PBOS, "COGL_FEATURE_PBOS", "pbos" },
        { COGL_FEATURE_UNSIGNED_INT_INDICES, "COGL_FEATURE_UNSIGNED_INT_INDICES", "unsigned-int-indices" },
        { COGL_FEATURE_DEPTH_RANGE, "COGL_FEATURE_DEPTH_RANGE", "depth-range" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglFeatureFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_buffer_target_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_WINDOW_BUFFER, "COGL_WINDOW_BUFFER", "window-buffer" },
        { COGL_OFFSCREEN_BUFFER, "COGL_OFFSCREEN_BUFFER", "offscreen-buffer" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglBufferTarget"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_texture_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_TEXTURE_NONE, "COGL_TEXTURE_NONE", "none" },
        { COGL_TEXTURE_NO_AUTO_MIPMAP, "COGL_TEXTURE_NO_AUTO_MIPMAP", "no-auto-mipmap" },
        { COGL_TEXTURE_NO_SLICING, "COGL_TEXTURE_NO_SLICING", "no-slicing" },
        { COGL_TEXTURE_NO_ATLAS, "COGL_TEXTURE_NO_ATLAS", "no-atlas" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglTextureFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_fog_mode_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_FOG_MODE_LINEAR, "COGL_FOG_MODE_LINEAR", "linear" },
        { COGL_FOG_MODE_EXPONENTIAL, "COGL_FOG_MODE_EXPONENTIAL", "exponential" },
        { COGL_FOG_MODE_EXPONENTIAL_SQUARED, "COGL_FOG_MODE_EXPONENTIAL_SQUARED", "exponential-squared" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglFogMode"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_blend_string_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_BLEND_STRING_ERROR_PARSE_ERROR, "COGL_BLEND_STRING_ERROR_PARSE_ERROR", "parse-error" },
        { COGL_BLEND_STRING_ERROR_ARGUMENT_PARSE_ERROR, "COGL_BLEND_STRING_ERROR_ARGUMENT_PARSE_ERROR", "argument-parse-error" },
        { COGL_BLEND_STRING_ERROR_INVALID_ERROR, "COGL_BLEND_STRING_ERROR_INVALID_ERROR", "invalid-error" },
        { COGL_BLEND_STRING_ERROR_GPU_UNSUPPORTED_ERROR, "COGL_BLEND_STRING_ERROR_GPU_UNSUPPORTED_ERROR", "gpu-unsupported-error" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglBlendStringError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_ERROR_MISSING_FEATURE, "COGL_ERROR_MISSING_FEATURE", "missing-feature" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl-vertex-buffer.h" */
#include "./cogl-vertex-buffer.h"

GType
cogl_attribute_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_ATTRIBUTE_TYPE_BYTE, "COGL_ATTRIBUTE_TYPE_BYTE", "byte" },
        { COGL_ATTRIBUTE_TYPE_UNSIGNED_BYTE, "COGL_ATTRIBUTE_TYPE_UNSIGNED_BYTE", "unsigned-byte" },
        { COGL_ATTRIBUTE_TYPE_SHORT, "COGL_ATTRIBUTE_TYPE_SHORT", "short" },
        { COGL_ATTRIBUTE_TYPE_UNSIGNED_SHORT, "COGL_ATTRIBUTE_TYPE_UNSIGNED_SHORT", "unsigned-short" },
        { COGL_ATTRIBUTE_TYPE_FLOAT, "COGL_ATTRIBUTE_TYPE_FLOAT", "float" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglAttributeType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_vertices_mode_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_VERTICES_MODE_POINTS, "COGL_VERTICES_MODE_POINTS", "points" },
        { COGL_VERTICES_MODE_LINE_STRIP, "COGL_VERTICES_MODE_LINE_STRIP", "line-strip" },
        { COGL_VERTICES_MODE_LINE_LOOP, "COGL_VERTICES_MODE_LINE_LOOP", "line-loop" },
        { COGL_VERTICES_MODE_LINES, "COGL_VERTICES_MODE_LINES", "lines" },
        { COGL_VERTICES_MODE_TRIANGLE_STRIP, "COGL_VERTICES_MODE_TRIANGLE_STRIP", "triangle-strip" },
        { COGL_VERTICES_MODE_TRIANGLE_FAN, "COGL_VERTICES_MODE_TRIANGLE_FAN", "triangle-fan" },
        { COGL_VERTICES_MODE_TRIANGLES, "COGL_VERTICES_MODE_TRIANGLES", "triangles" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglVerticesMode"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_indices_type_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_INDICES_TYPE_UNSIGNED_BYTE, "COGL_INDICES_TYPE_UNSIGNED_BYTE", "byte" },
        { COGL_INDICES_TYPE_UNSIGNED_SHORT, "COGL_INDICES_TYPE_UNSIGNED_SHORT", "short" },
        { COGL_INDICES_TYPE_UNSIGNED_INT, "COGL_INDICES_TYPE_UNSIGNED_INT", "int" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglIndicesType"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./cogl.h" */
#include "./cogl.h"

GType
cogl_buffer_bit_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_BUFFER_BIT_COLOR, "COGL_BUFFER_BIT_COLOR", "color" },
        { COGL_BUFFER_BIT_DEPTH, "COGL_BUFFER_BIT_DEPTH", "depth" },
        { COGL_BUFFER_BIT_STENCIL, "COGL_BUFFER_BIT_STENCIL", "stencil" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglBufferBit"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_read_pixels_flags_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GFlagsValue values[] = {
        { COGL_READ_PIXELS_COLOR_BUFFER, "COGL_READ_PIXELS_COLOR_BUFFER", "color-buffer" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_flags_register_static (g_intern_static_string ("CoglReadPixelsFlags"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}
GType
cogl_driver_error_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_DRIVER_ERROR_UNKNOWN_VERSION, "COGL_DRIVER_ERROR_UNKNOWN_VERSION", "unknown-version" },
        { COGL_DRIVER_ERROR_INVALID_VERSION, "COGL_DRIVER_ERROR_INVALID_VERSION", "invalid-version" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglDriverError"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* enumerations from "./winsys/cogl-texture-pixmap-x11.h" */
#include "./winsys/cogl-texture-pixmap-x11.h"

GType
cogl_texture_pixmap_x11_report_level_get_type (void)
{
  static volatile gsize g_enum_type_id__volatile = 0;

  if (g_once_init_enter (&g_enum_type_id__volatile))
    {
      static const GEnumValue values[] = {
        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_RAW_RECTANGLES, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_RAW_RECTANGLES", "raw-rectangles" },
        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_DELTA_RECTANGLES, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_DELTA_RECTANGLES", "delta-rectangles" },
        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_BOUNDING_BOX, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_BOUNDING_BOX", "bounding-box" },
        { COGL_TEXTURE_PIXMAP_X11_DAMAGE_NON_EMPTY, "COGL_TEXTURE_PIXMAP_X11_DAMAGE_NON_EMPTY", "non-empty" },
        { 0, NULL, NULL }
      };
      GType g_enum_type_id;

      g_enum_type_id =
        g_enum_register_static (g_intern_static_string ("CoglTexturePixmapX11ReportLevel"), values);

      g_once_init_leave (&g_enum_type_id__volatile, g_enum_type_id);
    }

  return g_enum_type_id__volatile;
}

/* Generated data ends here */

